@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.34 $
- * $Date: 1995/11/03 21:18:22 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/gopher/pager.c,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.3 $
+ * $Date: 2001/01/17 21:48:05 $
+ * $Source: /var/cvs/gopher/gopher/pager.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,15 @@
  *********************************************************************
  * Revision History:
  * $Log: pager.c,v $
+ * Revision 1.3  2001/01/17 21:48:05  jgoerzen
+ * Many fixes and tune-ups.  Now compiles cleanly with -Wall -Werror!
+ *
+ * Revision 1.2  2001/01/03 22:31:38  s2mdalle
+ * Inclusion of new header file
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.34  1995/11/03  21:18:22  lindner
  * ANSIfication
  *
@@ -81,6 +90,7 @@
 #include "CURcurses.h"
 #include "fileio.h"
 #include "Malloc.h"
+#include "pager.h"
 
 #ifdef VMS
 #include <stat.h>
@@ -394,7 +404,6 @@ PagerNextPage(CursesObj *cur, FILE *thefile, char *theline, int *bytecount, int
 
      /* Display a screen of text */
      for (i=0; i<LINES-4; i++) {
-     read_again:
 	  cp = fgets(theline, COLS+1, thefile);
 	  if (cp == NULL)
 	       break;
@@ -463,7 +472,6 @@ PagerSearch(FILE *thefile, char *theline, int *bytecount, char *search)
 	      return(FALSE);
 	    }
 	  for (i=0; i<LINES-4; i++) {
-	  search_again:
 	       cp = fgets(theline, COLS+1, thefile);
 	       if (cp == NULL)
 		    break;
